import system, { isClient } from '@/services/system';
import { identity } from 'lodash';

const keepSaveKeyMap = new Map();

const persistKeyName = '_persistKeys'; // key1,key2

const storage = {
  get(key: string) {
    return localStorage.getItem(key);
  },
  set(key: string, value: string, keep = false) {
    if (keep) {
      system.storage.set(key, value);
      // keepSaveKeyMap.set(key, true);
    }
    localStorage.setItem(key, value);
  },
  remove(key: string) {
    system.storage.remove(key);
    keepSaveKeyMap.delete(key);
    return localStorage.removeItem(key);
  },
  clear() {
    // 保留keep过的属性
    const tempStorage: { [key: string]: any } = {};
    keepSaveKeyMap.forEach((_, key) => {
      tempStorage[key] = storage.get(key);
    });
    localStorage.clear();
    keepSaveKeyMap.forEach((_, key) => {
      localStorage.setItem(key, tempStorage[key]);
    });
  },
  init() {
    if (window.initialStorage) {
      const hash = window.initialStorage || {};
      const kList = hash.keyList || [];

      kList.forEach((key: string) => {
        keepSaveKeyMap.set(key, true);
        storage.set(key, hash[key]);
      });
    }
  },
};

if (window.initialStorage) {
  storage.clear();
  const hash = window.initialStorage || {};
  const kList = hash.keyList || [];

  kList.forEach((key: string) => {
    keepSaveKeyMap.set(key, true);
    storage.set(key, hash[key]);
  });
}

export default storage;
